@@ -6,7 +6,8 @@
 "XVkbd.translations: #override \
 	<Message>WM_PROTOCOLS: DeleteWindowProc()\\n\
         <Configure>: WindowResized()\\n\
-        <MappingNotify>: ReadKeymap()",
+        <MappingNotify>: ReadKeymap()\\n\
+        <Visible>: VisibilityChanged()",
 "XVkbd.Form.translations: <BtnDown>:",
 "XVkbd.Form.?.translations: <BtnDown>:",
 "XVkbd*Command.translations: #override \\n\
@@ -121,10 +122,11 @@
 "XVkbd*menu.show_keypad.label: Show Keypad?",
 "XVkbd*menu.show_functionkey.label: Show Function Keys?",
 "XVkbd*menu.use_xtest.label: Use XTEST Extension?",
-"XVkbd*menu.quick_modifiers.label: Enable \"Quick Modifiers\"?",
+"XVkbd*menu.always_on_top.label: Always on Top?",
 "XVkbd*menu.shift_lock.label: Lock Shift?",
 "XVkbd*menu.altgr_lock.label: Lock AltGr?",
 "XVkbd*menu.modifiers_lock.label: Lock Control, Alt and Meta?",
+"XVkbd*menu.quick_modifiers.label: Enable \"Quick Modifiers\"?",
 "XVkbd*menu.open_display.label: Connect to Remote Display...",
 "XVkbd*menu.close_display.label: Revert to Local Display",
 "XVkbd*menu.quit.label: Quit",
@@ -146,10 +148,10 @@
 "XVkbd.display_panel*Label.width: 0",
 "XVkbd.display_panel*Label.resizable: true",
 "XVkbd*layout_panel.title: xvkbd - layout",
-"XVkbd*layout_panel*Command.width: 120",
+"XVkbd*layout_panel*Command.width: 150",
 "XVkbd*layout_panel*Command.height: 0",
 "XVkbd*layout_panel*vSpace: 2",
-"XVkbd*layout_panel.box.width: 260",
+"XVkbd*layout_panel.box.width: 320",
 "XVkbd*layout_panel.box.orientation: vertical",
 "XVkbd*completion_panel.title: xvkbd - word completion",
 "XVkbd*completion_panel*Label.justify: left",
@@ -222,7 +224,7 @@
 "XVkbd*deadkey_panel*dead_tilde.label: ~",
 "XVkbd*deadkey_panel*dead_abovedot.label: \\267",
 "XVkbd.customizations: default,belgian,danish,fitaly,french,french2,\
-  german,greek,hebrew,icelandic,italian,jisx6004/ja,korean/ko_KR.eucKR,\
+  german,greek,hebrew,icelandic,italian,jisx6002/ja,jisx6004/ja,korean/ko_KR.eucKR,\
   norwegian,portuguese,slovene,spanish,swedish,swissgerman,turkish,uk,latin1",
 "XVkbd*layout_panel*default.label: Default",
 "XVkbd*layout_panel*belgian.label: Belgian",
@@ -235,7 +237,8 @@
 "XVkbd*layout_panel*hebrew.label: Hebrew",
 "XVkbd*layout_panel*icelandic.label: Icelandic",
 "XVkbd*layout_panel*italian.label: Italian",
-"XVkbd*layout_panel*jisx6004.label: Japanese",
+"XVkbd*layout_panel*jisx6002.label: Japanese",
+"XVkbd*layout_panel*jisx6004.label: Japanese (JIS X 6004)",
 "XVkbd*layout_panel*korean.label: Korean",
 "XVkbd*layout_panel*norwegian.label: Norwegian",
 "XVkbd*layout_panel*portuguese.label: Portuguese",
@@ -246,3 +249,9 @@
 "XVkbd*layout_panel*turkish.label: Turkish",
 "XVkbd*layout_panel*uk.label: United Kingdom",
 "XVkbd*layout_panel*latin1.label: Latin-1",
+"XVkbd*Iconify.width: 20",
+"XVkbd*Iconify.shadowWidth: 0",
+"XVkbd*Iconify.resizable: false",
+"XVkbd*iconified_window*hSpace: 0",
+"XVkbd*iconified_window*vSpace: 0",
+"XVkbd*iconified_window*shadowWidth: 0",
