@@ -26,9 +26,11 @@ struct appres_struct {
   String geometry;
   Boolean debug;
   Boolean xtest;
+  Boolean no_sync;
   Boolean always_on_top;
   Boolean jump_pointer;
   Boolean jump_pointer_always;
+  Boolean jump_pointer_back;
   Boolean quick_modifiers;
   Boolean altgr_lock;
   Boolean shift_lock;
@@ -47,6 +49,7 @@ struct appres_struct {
   Boolean keypad_keysym;
   Boolean auto_add_keysym;
   Boolean list_widgets;
+  String positive_modifiers;
   String text;
   String file;
   String window;
